@@ -237,3 +237,16 @@ _sem_getvalue(SEM s,int * value)
 	return 0;
 }
 
+void
+throw_signal(int tid,int sig)
+{
+	pthread_kill(get_hard_tid(tid),sig);
+}
+
+
+
+void
+ss_do(void (*func)(void*),void * arg)
+{
+	(*func)(arg);
+}
