@@ -94,7 +94,7 @@ extern void _s_open(STREAM * s,int mode);
 	}
 	if ( func )
 		(*func)(1,work);
-	ret = d_alloc(sizeof(S_SOCKET),336);
+	ret = d_alloc(sizeof(S_SOCKET));
 	ret->h.tbl = &s_socket_table;
 	ret->h.thread = 0;
 	ret->_socket.fid = id;
