@@ -120,9 +120,9 @@ printf("FLAME SWITCH\n");
 	quality = get_sf_attribute(sf,l_string(std_cm,"quality"));	
 
 	if ( format )
-		gv_redraw_format = ll_copy_str(format,124);
+		gv_redraw_format = ll_copy_str(format);
 	if ( quality )
-		gv_redraw_quality = ll_copy_str(quality,124);
+		gv_redraw_quality = ll_copy_str(quality);
 
 	mode = get_el(s,1);
 	if ( get_type(mode) != XLT_INTEGER )
@@ -135,7 +135,7 @@ printf("FLAME SWITCH\n");
 	url = get_el(s,2);
 	if ( get_type(url) != XLT_STRING )
 		goto type_missmatch;
-	if ( get_url2(&view_agent_url,url->string.data,1209) < 0 )
+	if ( get_url2(&view_agent_url,url->string.data) < 0 )
 		goto param_error;
 	
 	set_env(gblisp_top_env0, l_string(std_cm,"win-flame-event"),
@@ -257,14 +257,14 @@ INDICATE * in, * in1;
 		*sts = sts_cache;
 		sts->indicate = 0;
 		for ( in = sts_cache.indicate ; in ; in = in->next ) {
-			in1 = d_alloc(sizeof(*in1),135);
+			in1 = d_alloc(sizeof(*in1));
 			*in1 = *in;
 			copy_url(&in1->url,&in->url);
 			in1->next = sts->indicate;
 			sts->indicate = in1;
 		}
 		if ( sts_cache.flame_base_unit )
-			sts->flame_base_unit = ll_copy_str(sts_cache.flame_base_unit,136);
+			sts->flame_base_unit = ll_copy_str(sts_cache.flame_base_unit);
 		unlock_task(view_agent_session_lock,"call_wf_status(1)");
 		return;
 	}
@@ -280,14 +280,14 @@ INDICATE * in, * in1;
 		sts_cache = *sts;
 		sts_cache.indicate = 0;
 		for ( in = sts->indicate ; in ; in = in->next ) {
-			in1 = d_alloc(sizeof(*in1),138);
+			in1 = d_alloc(sizeof(*in1));
 			*in1 = *in;
 			copy_url(&in1->url,&in->url);
 			in1->next = sts_cache.indicate;
 			sts_cache.indicate = in1;
 		}
 		if ( sts->flame_base_unit )
-			sts_cache.flame_base_unit = ll_copy_str(sts->flame_base_unit,137);
+			sts_cache.flame_base_unit = ll_copy_str(sts->flame_base_unit);
 		call_sts_cache_valid = 1;
 	}
 	unlock_task(view_agent_session_lock,"call_wf_status(2)");
@@ -379,8 +379,8 @@ XL_SEXP * result;
 		oh  = cflame.im->vimage.h;
 		p->h.type = GPT_ZOOM;
 		p->h.seq = ret;
-		p->z.index_x = d_alloc(sizeof(int)*ow,92);
-		p->z.index_y = d_alloc(sizeof(int)*oh,93);
+		p->z.index_x = d_alloc(sizeof(int)*ow);
+		p->z.index_y = d_alloc(sizeof(int)*oh);
 		wf_make_zoom_index(p->z.index_x,p->z.index_y,zoom,ow,oh);
 	}
 	return ret;
