@@ -229,7 +229,7 @@ L_CHAR * mode;
 			if ( mode ) {
 				if ( r->c.mode )
 					d_f_ree(r->c.mode);
-				r->c.mode = ll_copy_str(mode,123);
+				r->c.mode = ll_copy_str(mode);
 			}
 			goto end;
 		}
@@ -246,7 +246,7 @@ L_CHAR * mode;
 			c_url = compose_url(
 				get_url_str2(&r->h.entry),
 					obj->string.data);
-			get_url2(&u,c_url,123);
+			get_url2(&u,c_url);
 			m = get_mapping(r,&u);
 			free_url(&u);
 			d_f_ree(c_url);
@@ -264,7 +264,7 @@ L_CHAR * mode;
 		if ( mode ) {
 			if ( r->c.mode )
 				d_f_ree(r->c.mode);
-			r->c.mode = ll_copy_str(mode,111);
+			r->c.mode = ll_copy_str(mode);
 		}
 		for ( m = R_NEXT(MAP*,&r->c.map_children) ;
 				m != (MAP*)&r->c.map_children;
@@ -291,7 +291,7 @@ L_CHAR * mode;
 		if ( mode ) {
 			if ( r->c.mode )
 				d_f_ree(r->c.mode);
-			r->c.mode = ll_copy_str(mode,1245);
+			r->c.mode = ll_copy_str(mode);
 		}
 		return 0;
 	}
@@ -360,13 +360,13 @@ L_CHAR * str;
 	if ( str ) {
 		if ( r->c.relation_master )
 			d_f_ree(r->c.relation_master);
-		r->c.relation_master = ll_copy_str(str,124);
+		r->c.relation_master = ll_copy_str(str);
 	}
 	str = get_sf_attribute(sf,l_string(std_cm,"slave"));
 	if ( str ) {
 		if ( r->c.relation_slave )
 			d_f_ree(r->c.relation_slave);
-		r->c.relation_slave = ll_copy_str(str,125);
+		r->c.relation_slave = ll_copy_str(str);
 	}
 	return 0;
 }
@@ -459,26 +459,26 @@ ss_printf("* TIME = %i\n",index_time);
 				ret_name,ret_rs);
 			goto next;
 		}
-		get_url2(&url_buf,dest,1604);
+		get_url2(&url_buf,dest);
 		if ( url_cmp(&url_buf,&r->h.entry) != 0 ) {
 			free_url(&url_buf);
 			goto next;
 		}
 		free_url(&url_buf);
-		get_url2(&url_buf,name,1600);
+		get_url2(&url_buf,name);
 		for ( m = R_NEXT(MAP*,&r->c.map_children) ;
 				m != (MAP*)&r->c.map_children;
 				m = R_NEXT(MAP*,&m->h) )
 			if ( url_cmp(&m->src_url,&url_buf) == 0 )
 				goto next;
 		mod = get_el_by_symbol(sr,l_string(std_cm,"mod"),0);
-		m1 = d_alloc(sizeof(MAP),40);
+		m1 = d_alloc(sizeof(MAP));
 		m1->flags = 0;
 		m1->src = 0;
 		m1->map_file = 0;
 		m1->src_url = url_buf;
 		m1->clip = 0;
-		get_url2(&m1->map_url,map_file,1601);
+		get_url2(&m1->map_url,map_file);
 		m1->dest = r;
 		copy_url(&m1->dest_url,&r->h.entry);
 		m1->depth = depth;
@@ -576,7 +576,7 @@ URL url_buf;
 				ret_name,ret_rs);
 			goto next;
 		}
-		get_url2(&url_buf,name,1602);
+		get_url2(&url_buf,name);
 		for ( m = R_NEXT(MAP*,&r->c.map_parents) ;
 				m != (MAP*)&r->c.map_parents;
 				m = R_NEXT(MAP*,&m->h) )
@@ -584,12 +584,12 @@ URL url_buf;
 				goto next;
 
 
-		m1 = d_alloc(sizeof(MAP),41);
+		m1 = d_alloc(sizeof(MAP));
 		m1->flags = 0;
 		m1->dest = 0;
 		m1->map_file = 0;
 		m1->dest_url = url_buf;
-		get_url2(&m1->map_url,map_file,1603);
+		get_url2(&m1->map_url,map_file);
 		m1->src = r;
 		copy_url(&m1->src_url,&r->h.entry);
 		m1->depth = depth;
@@ -725,7 +725,7 @@ GEO_TYPE_TBL * a;
 				gt_macro[i].type&GT_D_MASK);
 		if ( (*dist)->parameter ) {
 			*param = d_alloc(sizeof(double)*
-					(*dist)->parameter,125);
+					(*dist)->parameter);
 			memcpy(*param,m->parameter,
 				sizeof(double)*(*dist)->parameter);
 		}
@@ -767,7 +767,7 @@ GEO_TYPE_TBL * a;
 		return;
 	}
 	type ++;
-	*param = d_alloc(sizeof(double)*(*dist)->parameter,135);
+	*param = d_alloc(sizeof(double)*(*dist)->parameter);
 	for ( ; *type && *type != ';' ; type ++ );
 	if ( *type == 0 ) {
 		d_f_ree(*param);
@@ -816,7 +816,7 @@ L_CHAR * b;
 	len = list_length(cid);
 	if ( len < 0 )
 		goto err;
-	c->cid = _cid = d_alloc(sizeof(int)*len,2436);
+	c->cid = _cid = d_alloc(sizeof(int)*len);
 	cid = cdr(cid);
 	_cid[0] = len;
 	for ( i = 1 ; i < len ; i ++, cid = cdr(cid) ) {
@@ -828,11 +828,11 @@ L_CHAR * b;
 	b = get_sf_attribute(sym->symbol.field,
 		l_string(std_cm,"body"));
 	if ( b )
-		c->body = ll_copy_str(b,1235);
+		c->body = ll_copy_str(b);
 	b = get_sf_attribute(sym->symbol.field,
 		l_string(std_cm,"pri"));
 	if ( b )
-		c->body_pri = ll_copy_str(b,1356);
+		c->body_pri = ll_copy_str(b);
 	return 0;
 err:
 	if ( c->cid )
@@ -1022,14 +1022,14 @@ RESOURCE * c;
 URL u;
 RESOURCE * ret;
 MAP * m;
-	get_url2(&u,crd,1229);
+	get_url2(&u,crd);
 	c = load_resource(ses,&u,Q_PRI_OBJ);
 	free_url(&u);
 	if ( c == 0 ) {
 		ret = 0;
 		goto end;
 	}
-	get_url2(&u,obj,1230);
+	get_url2(&u,obj);
 	for ( m = R_NEXT(MAP*,&c->c.map_children) ;
 			m != (MAP*)&c->c.map_children;
 			m = R_NEXT(MAP*,&m->h) ) {
