@@ -82,7 +82,7 @@ init_mp_cache(MP_CACHE * c)
 {
 int i;
 MP_ROUTE * r;
-	c->cache = d_alloc(sizeof(MP_ROUTE)*MP_ROUTE_CACHE_SIZE,22);
+	c->cache = d_alloc(sizeof(MP_ROUTE)*MP_ROUTE_CACHE_SIZE);
 	memset(c->cache,0,sizeof(MP_ROUTE)*MP_ROUTE_CACHE_SIZE);
 	c->root = &c->cache[0];
 	c->root->next = c->root->prev = c->root;
@@ -168,9 +168,9 @@ MP_ROUTE_T *
 new_mp_route_t(L_CHAR * start,L_CHAR * target,int flags)
 {
 MP_ROUTE_T * n;
-	n = new_queue_node(sizeof(*n),2346);
-	n->start = ll_copy_str(start,346);
-	n->target = ll_copy_str(target,346);
+	n = new_queue_node(sizeof(*n));
+	n->start = ll_copy_str(start);
+	n->target = ll_copy_str(target);
 	n->flags = flags;
 	n->route = 0;
 	n->mh = 0;
@@ -182,8 +182,8 @@ void
 _insert_purge_url(L_CHAR * url)
 {
 PURGE_URL * pm;
-	pm = d_alloc(sizeof(*pm),22);
-	pm->url = ll_copy_str(url,22);
+	pm = d_alloc(sizeof(*pm));
+	pm->url = ll_copy_str(url);
 	pm->next = 0;
 	if ( purge_url_head ) {
 		purge_url_tail->next = pm;
@@ -329,9 +329,9 @@ MP_ERR_ROUTE * er;
 			continue;
 		return er;
 	}
-	er = d_alloc(sizeof(*er),124);
-	er->head = ll_copy_str(head,115);
-	er->tail = ll_copy_str(tail,124);
+	er = d_alloc(sizeof(*er));
+	er->head = ll_copy_str(head);
+	er->tail = ll_copy_str(tail);
 	er->next = err_route_cache;
 	er->err_time = get_xltime();
 	err_route_cache = er;
@@ -435,14 +435,14 @@ _copy_route(MP_ROUTE * r)
 {
 MP_PATH * from, * to;
 MP_ROUTE * ret;
-	ret = d_alloc(sizeof(*ret),22);
+	ret = d_alloc(sizeof(*ret));
 	*ret = *r;
 	ret->head = ret->tail = 0;
 
 	for ( from = r->head ; from ; from = from->next ) {
-		to = d_alloc(sizeof(*to),3);
+		to = d_alloc(sizeof(*to));
 		*to = *from;
-		to->url = ll_copy_str(from->url,22);
+		to->url = ll_copy_str(from->url);
 		to->next = 0;
 		if ( ret->head ) {
 			ret->tail->next = to;
@@ -464,9 +464,9 @@ MP_PATH *
 copy_mp_path(MP_PATH * p)
 {
 MP_PATH * ret;
-	ret = d_alloc(sizeof(*ret),22);
+	ret = d_alloc(sizeof(*ret));
 	ret->next = 0;
-	ret->url = ll_copy_str(p->url,3);
+	ret->url = ll_copy_str(p->url);
 	return ret;
 }
 
@@ -514,11 +514,11 @@ _new_route2(MP_CACHE * cc,L_CHAR * start,L_CHAR * target)
 MP_ROUTE * r;
 MP_PATH * p1;
 	r = _new_route(cc);
-	r->head = p1 = d_alloc(sizeof(*p1),346);
-	p1->url = ll_copy_str(start,235);
+	r->head = p1 = d_alloc(sizeof(*p1));
+	p1->url = ll_copy_str(start);
 	p1->next = 0;
-	r->tail = p1 = d_alloc(sizeof(*p1),346);
-	p1->url = ll_copy_str(target,246);
+	r->tail = p1 = d_alloc(sizeof(*p1));
+	p1->url = ll_copy_str(target);
 	p1->next = 0;
 	r->lock = 0;
 	r->sts = RS_LOADING;
@@ -582,8 +582,8 @@ int f;
 	if ( f == 2 ) {
 		r->head = r->tail = 0;
 		for ( p1 = p_start ; ; p1 = p1->next ) {
-			p = d_alloc(sizeof(*p),1);
-			p->url = ll_copy_str(p1->url,1584);
+			p = d_alloc(sizeof(*p));
+			p->url = ll_copy_str(p1->url);
 			p->next = 0;
 			if ( r->head == 0 )
 				r->head = r->tail = p;
@@ -598,8 +598,8 @@ int f;
 	else {
 		r->head = r->tail = 0;
 		for ( p1 = p_target ; ; p1 = p1->next ) {
-			p = d_alloc(sizeof(*p),1);
-			p->url = ll_copy_str(p1->url,1585);
+			p = d_alloc(sizeof(*p));
+			p->url = ll_copy_str(p1->url);
 			p->next = r->head;
 			r->head = p;
 			if ( r->tail == 0 )
@@ -647,8 +647,8 @@ MP_PATH * ret,** retp,* path;
 	ret = 0;
 	retp = &ret;
 	for ( ; p ; p = p->next ) {
-		path = d_alloc(sizeof(*path),22);
-		path->url = ll_copy_str(p->url,333);
+		path = d_alloc(sizeof(*path));
+		path->url = ll_copy_str(p->url);
 		path->next = 0;
 		*retp = path;
 		retp = &path->next;
@@ -688,8 +688,8 @@ XL_SEXP * rec;
 		rec = car(list);
 		if ( get_type(rec) != XLT_STRING )
 			goto err;
-		p1 = d_alloc(sizeof(*p1),1245);
-		p1->url = ll_copy_str(rec->string.data,1586);
+		p1 = d_alloc(sizeof(*p1));
+		p1->url = ll_copy_str(rec->string.data);
 		p1->next = p;
 		p = p1;
 	}
@@ -1027,7 +1027,7 @@ rrr_check(L_CHAR * st)
 {
 int ret;
 URL u;
-	get_url2(&u,st,111);
+	get_url2(&u,st);
 	lock_task(route_lock);
 	if ( _rrr_search(&u) )
 		ret = 1;
@@ -1042,12 +1042,12 @@ rrr_insert(L_CHAR * st)
 {
 URL u;
 RRR_TYPE * r;
-	get_url2(&u,st,112);
+	get_url2(&u,st);
 	lock_task(route_lock);
 	r = _rrr_search(&u);
 	if ( r == 0 ) {
-		r = d_alloc(sizeof(*r),111);
-		r->server = ll_copy_str(u.server,115);
+		r = d_alloc(sizeof(*r));
+		r->server = ll_copy_str(u.server);
 		r->port = u.port;
 		r->cnt = 1;
 		r->next = rrr_list;
@@ -1065,7 +1065,7 @@ rrr_delete(L_CHAR * st)
 {
 URL u;
 RRR_TYPE * r, ** rp;
-	get_url2(&u,st,113);
+	get_url2(&u,st);
 	lock_task(route_lock);
 	r = _rrr_search(&u);
 	if ( r == 0 )
@@ -1090,7 +1090,7 @@ get_body(L_CHAR * url)
 {
 URL u;
 RESOURCE * r;
-	get_url2(&u,url,346);
+	get_url2(&u,url);
 	r = search_resource_by_entry(&u);
 	if ( r == 0 )
 		return 0;
@@ -1162,7 +1162,7 @@ ss_printf("RESOLVE_ERROR %ls %ls\n",n->start,n->target);
 			n->handle2_start = n->start;
 			n->handle2_target = n->target;
 		}
-		get_url2(&u,n->handle2_start,346);
+		get_url2(&u,n->handle2_start);
 		n->h.key = get_server_key(&u);
 		free_url(&u);
 		insert_queue(&rr_que1,n,1);
@@ -1265,7 +1265,7 @@ MP_ROUTE * r1, * r2;
 			set_attribute(cmd,
 				l_string(std_cm,"trigger"),
 				l_string(std_cm,"on"));
-		get_url2(&u,n->handle2_start,1612);
+		get_url2(&u,n->handle2_start);
 
 		n->get = remote_session(
 			gblisp_top_env0,
@@ -1390,7 +1390,7 @@ ss_printf("ERR RETRY %ls %ls\n",n->handle1_start,n->handle1_target);
 		n->handle2_start = tmp;
 		if ( n->h.key )
 			d_f_ree(n->h.key);
-		get_url2(&u,n->handle2_start,346);
+		get_url2(&u,n->handle2_start);
 		n->h.key = get_server_key(&u);
 		free_url(&u);
 
@@ -1451,7 +1451,7 @@ L_CHAR * map;
 		if ( !(mp->flags & RF_DIRTY) )
 			continue;
 		mp->flags &= ~RF_DIRTY;
-		el = d_alloc(sizeof(*el),22);
+		el = d_alloc(sizeof(*el));
 		el->mp = mp;
 		el->next = lst;	
 		lst = el;
@@ -1487,11 +1487,11 @@ identify_routing(L_CHAR * start)
 {
 MP_ROUTE * ret;
 MP_PATH * path;
-	ret = d_alloc(sizeof(*ret),22);
+	ret = d_alloc(sizeof(*ret));
 	memset(ret,0,sizeof(*ret));
-	ret->head = ret->tail = path = d_alloc(sizeof(*path),22);
+	ret->head = ret->tail = path = d_alloc(sizeof(*path));
 	memset(path,0,sizeof(*path));
-	path->url = ll_copy_str(start,33);
+	path->url = ll_copy_str(start);
 	ret->sts = RS_COPY;
 	ret->lock = 1;
 	return ret;
@@ -1678,7 +1678,7 @@ set_t_msg(2000);
 			continue;
 		if ( _ret != CRS_LOADING && loading_flag ) {
 			w = new_lrw(w);
-			get_url2(&w->url,crd_prev->url,1614);
+			get_url2(&w->url,crd_prev->url);
 			w->option = LRO_UNIT;
 			w->err = LRWE_HANDLING;
 		}
@@ -1721,7 +1721,7 @@ set_t_msg(2001);
 			continue;
 		if ( _ret != CRS_LOADING && loading_flag ) {
 			w = new_lrw(w);
-			get_url2(&w->url,map->url,1614);
+			get_url2(&w->url,map->url);
 			w->err = LRWE_HANDLING;
 		}
 		switch ( _ret ) {
@@ -1778,7 +1778,7 @@ set_cpu_msg(2000);
 			er_panic("get_mh_from_route");
 		}
 		w = new_lrw(w);
-		get_url2(&w->url,crd_prev->url,1614);
+		get_url2(&w->url,crd_prev->url);
 		w->option = LRO_UNIT;
 		w->err = LRWE_HANDLING;
 	}
@@ -1806,7 +1806,7 @@ set_cpu_msg(2001);
 			er_panic("get_mh_from_route");
 		}
 		w = new_lrw(w);
-		get_url2(&w->url,map->url,1614);
+		get_url2(&w->url,map->url);
 		w->err = LRWE_HANDLING;
 	}
 set_cpu_msg(2002);
@@ -1836,7 +1836,7 @@ set_cpu_msg(2003);
 			print_mpr(mpr);
 			er_panic("get_mh_from_route");
 		}
-		get_url2(&uu,map->url,1614);
+		get_url2(&uu,map->url);
 		r = get_lrw(w,&uu);
 		free_url(&uu);
 		if ( r == 0 ) {
@@ -1844,9 +1844,9 @@ set_cpu_msg(2003);
 			insert_purge_url(map->url);
 			goto nx1;
 		}
-		get_url2(&uu,crd_prev->url,1615);
+		get_url2(&uu,crd_prev->url);
 		if ( url_cmp(&uu,&r->map.src) == 0 ) {
-			get_url2(&uu,crd_next->url,122);
+			get_url2(&uu,crd_next->url);
 			if ( url_cmp(&uu,&r->map.dest) ) {
 				err_flag = 1;
 				insert_purge_url(map->url);
@@ -1860,7 +1860,7 @@ set_cpu_msg(2003);
 				insert_purge_url(map->url);
 				goto nx1;
 			}
-			get_url2(&uu,crd_next->url,222);
+			get_url2(&uu,crd_next->url);
 			if ( url_cmp(&uu,&r->map.src) ) {
 				err_flag = 1;
 				insert_purge_url(map->url);
@@ -1878,7 +1878,7 @@ set_cpu_msg(2004);
 	free_lrw_req_next(w);
 set_cpu_msg(2005);
 
-	get_url2(&uu,mpr->head->url,1617);
+	get_url2(&uu,mpr->head->url);
 	if ( url_cmp(&uu,u) == 0 ) {
 		ret1 = rev_mh(ret);
 		free_mh(ret);
@@ -1911,7 +1911,7 @@ MAP_HISTORY * mh;
 		return MP_MH_NO_ROUTE;
 	if ( mpr == 0 )
 		return 0;
-	get_url2(&u,org,1618);
+	get_url2(&u,org);
 	mh = get_mh_from_route(ses,&u,mpr);
 	free_url(&u);
 	flush_route(mpr);
@@ -2011,7 +2011,7 @@ retry:
 	}
 	if ( mpr == 0 )
 		return CRT_EXIST;
-	get_url2(&u,org,1618);
+	get_url2(&u,org);
 	ret = check_mh_from_route(&u,mpr,loading_flag);
 	free_url(&u);
 	flush_route(mpr);
