@@ -846,7 +846,7 @@ char * e_param;
 	}
 	if ( r->c.mode )
 		d_f_ree(r->c.mode);
-	r->c.mode = ll_copy_str(_mode,1234);
+	r->c.mode = ll_copy_str(_mode);
 	for ( s = cdr(case_list) ; get_type(s) == XLT_PAIR ; s = cdr(s) ) {
 		ret = eval(env,car(s));
 		if ( get_type(ret) == XLT_ERROR ) {
@@ -975,11 +975,11 @@ int reso_cnt,minus_cnt,rect_cnt;
 				break;
 			dw1 = *dw;
 			dw1.parent = dw;
-			dw1.pt_list = d_alloc(sizeof(GB_POINT)*dw1.size,42);
+			dw1.pt_list = d_alloc(sizeof(GB_POINT)*dw1.size);
 			dw1.limit_reso = 0;
 			memcpy(dw1.pt_list,dw->pt_list,
 				dw1.size*sizeof(GB_POINT));
-			dw1.pt_reso = d_alloc(sizeof(REAL1)*dw1.size,43);
+			dw1.pt_reso = d_alloc(sizeof(REAL1)*dw1.size);
 			memcpy(dw1.pt_reso,dw->pt_reso,dw1.size*sizeof(REAL1));
 
 reso_cnt = 0;
