@@ -67,7 +67,7 @@ OBJ * o;
 	}
 	if ( R_NEXT(RING_TYPE*,&o->polygon2d.point_list)
 			== &o->polygon2d.point_list ) {
-		sl = d_alloc(sizeof(*sl),25);
+		sl = d_alloc(sizeof(*sl));
 		sl->obj = o;
 		sl->next = w->sl;
 		w->sl = sl;
@@ -643,7 +643,7 @@ int ind_cnt;
 	if ( er < 0 )
 		return -1;
 	p1_i = gb2i_point(p1);
-	fill_buf = d_alloc(w*h,45);
+	fill_buf = d_alloc(w*h);
 	for ( i = 0 ; i < w*h ; i ++ )
 		fill_buf[i] = 0;
 
@@ -1078,7 +1078,7 @@ int fg,fg2;
 	p1_i = gb2i_point(p1);
 	w = minrect->br.x - minrect->tl.x;
 	h = minrect->br.y - minrect->tl.y;
-	fill_buf = d_alloc(w*h,46);
+	fill_buf = d_alloc(w*h);
 	for ( i = 0 ; i < w*h ; i ++ )
 		fill_buf[i] = 0;
 	last_i = p1_i;
@@ -1188,7 +1188,7 @@ int w,h,i;
 		return 1;
 	w = minrect.br.x - minrect.tl.x;
 	h = minrect.br.y - minrect.tl.y;
-	sw->si->pixels = d_alloc(sizeof(long)*w*h,47);
+	sw->si->pixels = d_alloc(sizeof(long)*w*h);
 	for ( i = 0 ; i < w*h ; i ++ )
 		sw->si->pixels[i] = C_TRANSPARENT;
 	sw->si->x = minrect.tl.x;
