@@ -112,7 +112,7 @@ _insert_indicate(URL * u)
 INDICATE * in, ** inp;
 	in = _search_indicate(u);
 	if ( in == 0 ) {
-		in = d_alloc(sizeof(*in),50);
+		in = d_alloc(sizeof(*in));
 		copy_url(&in->url,u);
 		in->status = 0;
 		in->next = 0;
@@ -142,7 +142,7 @@ _copy_indicate()
 INDICATE * ret, * in, * in1;
 	ret = 0;
 	for ( in = env.indicate ; in ; in = in->next ) {
-		in1 = d_alloc(sizeof(*in1),135);
+		in1 = d_alloc(sizeof(*in1));
 		*in1 = *in;
 		copy_url(&in1->url,&in->url);
 		in1->next = ret;
@@ -216,7 +216,7 @@ _copy_infolist()
 INFO_LIST * il_1,*il_2,* ret;
 	ret = 0;
 	for ( il_1 = env.infolist ; il_1 ; il_1 = il_1->next ) {
-		il_2 = d_alloc(sizeof(*il_2),1504);
+		il_2 = d_alloc(sizeof(*il_2));
 		*il_2 = *il_1;
 		il_2->next = ret;
 		ret = il_2;
@@ -254,7 +254,7 @@ INFO_LIST * il;
 	if ( (o->h.flags&OF_INFO_STS) == OF_INFO_FETCH &&
 			 o->h.info_org == 0 )
 		goto end;
-	il = d_alloc(sizeof(*il),47);
+	il = d_alloc(sizeof(*il));
 	il->obj = o;
 	il->flags = o->h.flags&(~OF_INFO_STS);
 	il->code = o->h.code;
@@ -314,10 +314,10 @@ void
 click_info_url(L_CHAR * url)
 {
 GBVIEW_STATUS * sts;
-	sts = d_alloc(sizeof(*sts),14);
+	sts = d_alloc(sizeof(*sts));
 	wf_init_status(sts);
 	sts->flags = SF_REFERENCE;
-	sts->reference = ll_copy_str(url,15);
+	sts->reference = ll_copy_str(url);
 	new_tick(_click_event_tick,0,(int)sts);
 }
 
@@ -325,7 +325,7 @@ void
 click_infolist()
 {
 GBVIEW_STATUS * sts;
-	sts = d_alloc(sizeof(*sts),14);
+	sts = d_alloc(sizeof(*sts));
 	wf_init_status(sts);
 	sts->flags = SF_INFOLIST;
 	sts->infolist = _copy_infolist();
@@ -336,7 +336,7 @@ void
 click_info_error()
 {
 GBVIEW_STATUS * sts;
-	sts = d_alloc(sizeof(*sts),125);
+	sts = d_alloc(sizeof(*sts));
 	wf_init_status(sts);
 	sts->flags = SF_ERROR;
 	new_tick(_click_event_tick,0,(int)sts);
@@ -397,7 +397,7 @@ insert_irq(RESOURCE * r,int code,int cmd,WF_ID wfid)
 INFO_REQ_QUEUE * ir;
 INDICATE_T * it;
 	lock_task(irq_lock);
-	ir = d_alloc(sizeof(*ir),235);
+	ir = d_alloc(sizeof(*ir));
 	ir->code = code;
 	ir->cmd = cmd;
 if ( wfid == 0 )
@@ -408,7 +408,7 @@ printf("??????????????? insert_irq\n");
 	irq_cnt ++;
 	unlock_task(irq_lock,"insert_irq");
 
-	it = d_alloc(sizeof(*it),22);
+	it = d_alloc(sizeof(*it));
 	memset(it,0,sizeof(*it));
 	it->r = r;
 	insert_queue(&req_indicate,it,1);
@@ -724,7 +724,7 @@ XL_SEXP * card_data;
 int ind;
 char * err_buf;
 	ind = 0;
-	err_buf = d_alloc(100,123);
+	err_buf = d_alloc(100);
 
 	for ( ; get_type(info) == XLT_PAIR ; info = cdr(info) ) {
 		s = car(info);
