@@ -123,11 +123,11 @@ int i;
 	default:
 		env.win_height = 400;
 	}
-	env.redraw = d_alloc(env.win_height*env.win_width,49);
+	env.redraw = d_alloc(env.win_height*env.win_width);
 	for ( i = 0 ; i < env.win_height*env.win_width ; i ++ )
 		env.redraw[i] = RP_REDRAW;
 	env.redraw_plane 
-		= d_alloc(env.win_height*env.win_width*sizeof(long),50);
+		= d_alloc(env.win_height*env.win_width*sizeof(long));
 	return 0;
 }
 
@@ -305,7 +305,7 @@ XL_SEXP * ret;
 	default:
 		goto typemissmatch;
 	}
-	get_url2(&url_buf,coord_name->string.data,1203);
+	get_url2(&url_buf,coord_name->string.data);
 	if ( l_strcmp(type->string.data,l_string(std_cm,"transparent")) == 0 )
 	  			{
 		ret = overlay_transparent(&url_buf,e,s);
@@ -378,7 +378,7 @@ int flags;
 		flags |= IF_OBJECT;
 	else 	goto typemissmatch;
 
-	get_url2(&i_url,name->string.data,1204);
+	get_url2(&i_url,name->string.data);
 	set_pointer_indicate(flags,&i_url);
 
 	free_url(&i_url);
@@ -513,7 +513,7 @@ xl_status_param(XLISP_ENV * env,XL_SEXP * s)
 {
 char * file;
 STREAM * st;
-	file = d_alloc(100,22);
+	file = d_alloc(100);
 	sprintf(file,"%s%s",get_preference_path(),GBVIEW_PARAM);
 	st = s_open_file(file,O_RDONLY);
 	d_f_ree(file);
@@ -639,7 +639,7 @@ xl_write_status(XLISP_ENV * e,XL_SEXP * s)
 {
 char * file;
 STREAM * st;
-	file = d_alloc(100,22);
+	file = d_alloc(100);
 	sprintf(file,"%s%s",get_preference_path(),GBVIEW_PARAM);
 	st = s_open_file(file,O_RDWR|O_CREAT|O_TRUNC);
 	d_f_ree(file);
@@ -679,7 +679,7 @@ xl_reset_status(XLISP_ENV * e,XL_SEXP * s)
 STREAM * st;
 char * file;
 
-	file = d_alloc(100,22);
+	file = d_alloc(100);
 	sprintf(file,"%s%s",get_preference_path(),GBVIEW_PARAM);
 	u_mkdir(get_preference_path(),0700);
 	st = s_open_file(file,
@@ -769,7 +769,7 @@ loading_from_network(L_CHAR * url, XLISP_ENV * e)
 URL u;
 int ses;
 XL_SEXP * ret, * lst;
-	if ( get_url2(&u, url, 1315) < 0 ) {
+	if ( get_url2(&u, url) < 0 ) {
 		return get_error(
 			0,0,
 			XLE_PROTO_INV_PARAM,
@@ -824,7 +824,7 @@ STREAM * st;
 
 	gc_push(0,0,"open_control_port");
 
-	file = d_alloc(1000,123);
+	file = d_alloc(1000);
 
 	port = 9102 + (get_xltime() % (10000 - 9102));
 	for ( ; ; ) {
@@ -895,7 +895,7 @@ STREAM * st;
 	gc_push(0,0,"load_parameter");
 	
 	e = new_env(gblisp_top_env1);
-	file = d_alloc(1000,123);
+	file = d_alloc(1000);
 
 	if ( parameter && l_strcmp(parameter, l_string(std_cm,"local")) != 0 ) {
 		ret = loading_from_network(parameter, e);
@@ -960,7 +960,7 @@ struct dirent * d;
 	gc_push(0,0,"load_peripheral");
 
 	env = new_env(gblisp_top_env1);
-	file = d_alloc(1000,234);
+	file = d_alloc(1000);
 
 	if ( l_strcmp(peripheral, l_string(std_cm, "local")) != 0 ) {
 		ret = loading_from_network(peripheral, env);
@@ -1026,13 +1026,13 @@ extern int preference_script_length;
 L_CHAR * parameter = 0, * peripheral = 0;
 	
 	if ( parameter1 )
-		parameter = ll_copy_str(parameter1,1314);
+		parameter = ll_copy_str(parameter1);
 	if ( peripheral1 )
-		peripheral = ll_copy_str(peripheral1,1314);
+		peripheral = ll_copy_str(peripheral1);
 
 	/* setup preference path (gbview.param / gbview.ap) */
 
-	file = d_alloc(1000,234);
+	file = d_alloc(1000);
 	pid = getpid();
 	sprintf(file,"%s",get_preference_path());
 	set_env(gblisp_top_env1,l_string(std_cm,"gv-initdir"),
