@@ -189,9 +189,9 @@ int i;
 	radar_lock = new_lock(LL_RADAR);
 	query_lock = new_lock(LL_RADAR_QUERY);
 	rc.win_reso_window = WIN_RESO_WINDOW_MAX;
-	rc.crd = d_alloc(sizeof(RADAR_CRD)*RADAR_CACHE_SIZE,12);
-	rc.ptr = d_alloc(sizeof(GB_POINT)*RADAR_CACHE_SIZE*8,13);
-	rc.res = d_alloc(sizeof(REAL1)*RADAR_CACHE_SIZE*8,14);
+	rc.crd = d_alloc(sizeof(RADAR_CRD)*RADAR_CACHE_SIZE);
+	rc.ptr = d_alloc(sizeof(GB_POINT)*RADAR_CACHE_SIZE*8);
+	rc.res = d_alloc(sizeof(REAL1)*RADAR_CACHE_SIZE*8);
 	rc.free_list = 0;
 	for ( i = 1 ; i < RADAR_CACHE_SIZE ; i ++ ) {
 		rc.crd[i].bufid = i;
@@ -293,7 +293,7 @@ void
 insert_beam_to_resource(XL_SEXP * urls)
 {
 T_BEAM_TO_RESOURCE * n;
-	n = new_queue_node(sizeof(*n),236);
+	n = new_queue_node(sizeof(*n));
 	n->h.key = 0;
 	n->h.ins = 0;
 	n->urls = urls;
@@ -630,7 +630,7 @@ void
 _insert_radar_lump(RADAR_CRD * c,RADAR_LUMP * rl)
 {
 LUMP_CRD_NODE * n;
-	n = d_alloc(sizeof(*n),12);
+	n = d_alloc(sizeof(*n));
 	n->crd = c;
 	n->lump = rl;
 	n->crd_next = c->lump;
@@ -678,11 +678,11 @@ _copy_radar_lump(RADAR_LUMP * l)
 RADAR_LUMP * ret, * ll;
 	ret = 0;
 	for ( ; l ; l = l->next ) {
-		ll = d_alloc(sizeof(*ll),1651);
+		ll = d_alloc(sizeof(*ll));
 		*ll = *l;
 		ll->crd = 0;
-		ll->db_path = ll_copy_str(ll->db_path,1511);
-		ll->lumpcrd_path = ll_copy_str(ll->lumpcrd_path,1512);
+		ll->db_path = ll_copy_str(ll->db_path);
+		ll->lumpcrd_path = ll_copy_str(ll->lumpcrd_path);
 		ll->next = ret;
 		ret = ll;
 	}
@@ -719,9 +719,9 @@ _new_radar_lump(L_CHAR * crd,L_CHAR * db)
 {
 RADAR_LUMP * l;
 
-	l = d_alloc(sizeof(*l),1);
-	l->lumpcrd_path = ll_copy_str(crd,1513);
-	l->db_path = ll_copy_str(db,1514);
+	l = d_alloc(sizeof(*l));
+	l->lumpcrd_path = ll_copy_str(crd);
+	l->db_path = ll_copy_str(db);
 	l->next = 0;
 	l->crd = 0;
 	return l;
@@ -758,11 +758,11 @@ int er;
 
 
 	l = 0;
-	db_path = ll_copy_str(db,1515);
+	db_path = ll_copy_str(db);
 	len = l_strlen(db_path);
 	db_path = d_re_alloc(db_path,(len + 10)*sizeof(L_CHAR));
 	l_strcpy(&db_path[len],l_string(std_cm,"db.pmd"));
-	get_url2(&u,crd,1552);
+	get_url2(&u,crd);
 	if ( u.resource )
 		d_f_ree(u.resource);
 	u.resource = nl_copy_str(std_cm,"db.pmd");
@@ -882,8 +882,8 @@ int ret_f;
 			unlock_task(radar_lock,"retrieve_lump");
 			continue;
 		}
-		crd = ll_copy_str(c->crd_path,1516);
-		obj = ll_copy_str(c->obj_path,1517);
+		crd = ll_copy_str(c->crd_path);
+		obj = ll_copy_str(c->obj_path);
 		unlock_task(radar_lock,"retrieve_lump");
 		lmp = load_meta(ses,"lump",crd);
 		if ( get_type(lmp) == XLT_ERROR )
@@ -1165,7 +1165,7 @@ _new_radar_matrix()
 int x,y;
 RADAR_MATRIX * ret;
 
-	ret = d_alloc(sizeof(*ret),124);
+	ret = d_alloc(sizeof(*ret));
 	for ( x = 0 ; x < 2 ; x ++ )
 		for ( y = 0 ; y < 2 ; y ++ )
 			ret->mx[x][y] = 0;
@@ -1293,7 +1293,7 @@ _new_radar_matrix_list(RADAR_MATRIX * mx)
 {
 RADAR_MATRIX_LIST * ret;
 
-	ret = d_alloc(sizeof(*ret),125);
+	ret = d_alloc(sizeof(*ret));
 	ret->mx = mx;
 	ret->next = 0;
 	return ret;
@@ -1483,7 +1483,7 @@ RADAR_NODE * n;
 	for ( n = mx->list ; n ; n = n->matrix_next )
 		if ( n->crd == c )
 			return;
-	n = d_alloc(sizeof(*n),125);
+	n = d_alloc(sizeof(*n));
 	n->matrix = mx;
 	n->crd = c;
 	n->matrix_next = mx->list;
@@ -1743,8 +1743,8 @@ set_t_msg(100);
 
 	w = 0;
 	url = c->crd_path;
-	get_url2(&u,url,1553);
-	get_url2(&u2,rc.base_url,1554);
+	get_url2(&u,url);
+	get_url2(&u2,rc.base_url);
 set_t_msg(101);
 	if ( url_cmp(&u,&u2) == 0 ) {
 
@@ -1754,7 +1754,7 @@ set_t_msg(101);
 		mpr = 0;
 		if ( c->base_url )
 			d_f_ree(c->base_url);
-		c->base_url = ll_copy_str(rc.base_url,123);
+		c->base_url = ll_copy_str(rc.base_url);
 		goto same;
 	}
 	free_url(&u);
@@ -1762,10 +1762,10 @@ set_t_msg(101);
 set_t_msg(102);
 	if ( c->base_url )
 		d_f_ree(c->base_url);
-	c->base_url = ll_copy_str(rc.base_url,123);
+	c->base_url = ll_copy_str(rc.base_url);
 	{
 	L_CHAR * tmp;
-		tmp = ll_copy_str(rc.base_url,123);
+		tmp = ll_copy_str(rc.base_url);
 		mpr = resolve_route(tmp,url,RR_WM_INDIRECT);
 		d_f_ree(tmp);
 	}
@@ -1773,7 +1773,7 @@ set_t_msg(102);
 		ret = -1;
 		goto end;
 	}
-	get_url2(&u,rc.base_url,1555);
+	get_url2(&u,rc.base_url);
 	mh = get_mh_from_route(ses,&u,mpr);
 	free_url(&u);
 	if ( mh == MP_MH_NO_ROUTE ) {
@@ -1795,11 +1795,11 @@ set_t_msg(104);
 		map_r = 0;
 	}
 set_t_msg(105);
-	get_url2(&u,c->obj_path,1556);
+	get_url2(&u,c->obj_path);
 	w = new_lrw(0);
-	get_url2(&w->url,c->crd_path,123);
+	get_url2(&w->url,c->crd_path);
 	w = new_lrw(w);
-	get_url2(&w->url,c->obj_path,123);
+	get_url2(&w->url,c->obj_path);
 	load_resource_list(w,Q_PRI_RADAR,1);
 	r = get_lrw(w,&u);
 	if ( r == 0 )
@@ -1844,7 +1844,7 @@ set_t_msg(107);
 		map_conv_forward(map_r,ptr,reso,8);
 set_t_msg(108);
 
-	get_url2(&u,c->crd_path,1557);
+	get_url2(&u,c->crd_path);
 	r = get_lrw(w,&u);
 set_t_msg(109);
 	if ( r == 0 )
@@ -1945,18 +1945,18 @@ c->minrect.br.y);
 		goto flush_end;
 	}
 	w = new_lrw(0);
-	get_url2(&w->url,crd,1234);
+	get_url2(&w->url,crd);
 	w = new_lrw(w);
-	get_url2(&w->url,obj,1234);
+	get_url2(&w->url,obj);
 	load_resource_list(w,Q_PRI_RADAR,1);
 
-	get_url2(&u,crd,1234);
+	get_url2(&u,crd);
 	r = get_lrw(w,&u);
 	free_url(&u);
 	if ( r == 0 )
 		goto flush_end;
 
-	get_url2(&u,obj,1234);
+	get_url2(&u,obj);
 	r2 = get_lrw(w,&u);
 	free_url(&u);
 	if ( r2 == 0 )
@@ -1964,9 +1964,9 @@ c->minrect.br.y);
 
 
 	c = new_radar_crd();
-	c->crd_path = ll_copy_str(crd,1518);
-	c->obj_path = ll_copy_str(obj,1519);
-	c->base_url = ll_copy_str(rc.base_url,1520);
+	c->crd_path = ll_copy_str(crd);
+	c->obj_path = ll_copy_str(obj);
+	c->base_url = ll_copy_str(rc.base_url);
 
 	c->crd_bib = copy_bib_list(r->h.bib);
 	c->obj_bib = copy_bib_list(r2->h.bib);
@@ -2071,27 +2071,27 @@ ss_printf("NEXT %i\n",next);
 
 		goto last;
 	}
-	new = ll_copy_str(get_url_str2(&draw->h.entry),1521);
+	new = ll_copy_str(get_url_str2(&draw->h.entry));
 
 
 
 	if ( rc.base_url == 0 ) {
 
 		free_radar_matrix();
-		rc.base_url = ll_copy_str(new,1522);
+		rc.base_url = ll_copy_str(new);
 		goto end;
 	}
 
 
 	{
 	L_CHAR * tmp;
-		tmp = ll_copy_str(rc.base_url,124);
+		tmp = ll_copy_str(rc.base_url);
 		mpr = resolve_route(tmp,new,RR_WM_INDIRECT);
 		d_f_ree(tmp);
 	}
 	if ( mpr == 0 || mpr == MP_NO_ROUTE )
 		goto end;
-	get_url2(&u,rc.base_url,1558);
+	get_url2(&u,rc.base_url);
 
 
 	mh = get_mh_from_route(ses,&u,mpr);
@@ -2149,7 +2149,7 @@ ss_printf("REMAKE %ls --> ",rc.base_url);
 /*
 ss_printf("%ls\n",new);
 */
-	rc.base_url = ll_copy_str(new,1523);
+	rc.base_url = ll_copy_str(new);
 
 end_flush:
 	flush_route(mpr);
@@ -2204,8 +2204,8 @@ unsigned int t;
 		wfid = wf_get(no);
 		if ( wfid == 0 )
 			break;
-		cl = d_alloc(sizeof(*cl),1212);
-		a = d_alloc(sizeof(*a),1213);
+		cl = d_alloc(sizeof(*cl));
+		a = d_alloc(sizeof(*a));
 		cl->wfid = wfid;
 		cl->crd = 0;
 		if ( t - wf_insert_time(wfid) > 10 )
@@ -2276,7 +2276,7 @@ CRD_LIST * cl;
 	cl = a->data;
 	if ( cl->crd == 0 )
 		return 0;
-	a1 = d_alloc(sizeof(*a1),1234);
+	a1 = d_alloc(sizeof(*a1));
 	a1->data = cl;
 	avt_insert(tree,a1,cmp_reso_sort);
 	return 0;
@@ -2346,11 +2346,11 @@ r->br.y);
 				}
 			}
 			else {
-				clp = d_alloc(sizeof(*clp),1251);
+				clp = d_alloc(sizeof(*clp));
 				clp->wfid = 0;
 				clp->crd = c;
 				clp->sts = CLS_INSERT;
-				a = d_alloc(sizeof(*a),1252);
+				a = d_alloc(sizeof(*a));
 				a->data = clp;
 				avt_insert(tree,a,cmp_wf_crd);
 			}
@@ -2451,14 +2451,14 @@ ss_printf("WIF *  %x\n",cl);
 	}
 
 
-	get_url2(&u,cl->crd->crd_path,1559);
+	get_url2(&u,cl->crd->crd_path);
 
 	r = load_resource(w->ses,&u,Q_PRI_RADAR);
 set_cpu_msg(106);
 	free_url(&u);
 	{
 	L_CHAR * tmp;
-		tmp = ll_copy_str(rc.base_url,126);
+		tmp = ll_copy_str(rc.base_url);
 		mpr = resolve_route(tmp,cl->crd->crd_path,RR_WM_INDIRECT);
 		d_f_ree(tmp);
 	}
@@ -2976,7 +2976,7 @@ retry:
 	w.wfid = wf_get_current();
 	w.ret = 0;
 	w.reso_min = -1;
-	get_url2(&w.u,rc.base_url,1560);
+	get_url2(&w.u,rc.base_url);
 
 	avt_trace_from_small(wf_tree,win_insert_func,&w);
 	avt_trace_from_small(wf_tree,win_delete_func,&w);
@@ -3516,13 +3516,13 @@ T_LOAD_TO_BEAM * n;
 		_conv_r = n->r;
 		base_url = n->base_url;
 
-		get_url2(&target,rl->lumpcrd_path,1561);
+		get_url2(&target,rl->lumpcrd_path);
 		if ( target.resource )
 			d_f_ree(target.resource);
-		target.resource = ll_copy_str(rl->db_path,1524);
+		target.resource = ll_copy_str(rl->db_path);
 		qqq = 0;
 		for ( rl2 = rl ; rl2 ; ) {
-			get_url2(&u,rl2->lumpcrd_path,1562);
+			get_url2(&u,rl2->lumpcrd_path);
 			conv_min = _conv_min;
 			conv_max = _conv_max;
 			conv_r = _conv_r;
@@ -3539,7 +3539,7 @@ T_LOAD_TO_BEAM * n;
 			if ( u.resource )
 				d_f_ree(u.resource);
 
-			u.resource = ll_copy_str(rl2->db_path,1525);
+			u.resource = ll_copy_str(rl2->db_path);
 			qq = List(n_get_symbol("pmd-query"),
 				get_string(rl2->db_path),
 				List(n_get_symbol("quote"),
@@ -3648,7 +3648,7 @@ T_LOAD_TO_BEAM * n;
 	_rlock_base_url("base_to_remote");
 
 	rl = _copy_radar_lump(rc.lump);
-	base_url = ll_copy_str(rc.base_url,1527);
+	base_url = ll_copy_str(rc.base_url);
 
 	_unlock_base_url();
 
@@ -3657,11 +3657,11 @@ T_LOAD_TO_BEAM * n;
 
 
 	for ( ; rl ; ) {
-		get_url2(&target,rl->lumpcrd_path,1563);
+		get_url2(&target,rl->lumpcrd_path);
 		rl2 = 0;
 		for ( rlp = &rl ; *rlp ; ) {
 			rl3 = *rlp;
-			get_url2(&u,rl3->lumpcrd_path,1564);
+			get_url2(&u,rl3->lumpcrd_path);
 			if ( l_strcmp(target.server,u.server) == 0 &&
 					target.port == u.port ) {
 				*rlp = rl3->next;
@@ -3673,13 +3673,13 @@ T_LOAD_TO_BEAM * n;
 			}
 			free_url(&u);
 		}
-		n = new_queue_node(sizeof(*n),236);
-		n->h.key = ll_copy_str(target.server,125);
+		n = new_queue_node(sizeof(*n));
+		n->h.key = ll_copy_str(target.server);
 		n->query = q;
 		n->r = *r;
 		n->min = min;
 		n->max = max;
-		n->base_url = ll_copy_str(base_url,125);
+		n->base_url = ll_copy_str(base_url);
 		n->rl = rl2;
 
 		insert_queue(&rc.load_to_beam,n,0);
@@ -3750,7 +3750,7 @@ L_CHAR * bu;
 
 	rlock_base_url("beam_load");
 	if ( rc.base_url )
-		bu = ll_copy_str(rc.base_url,346);
+		bu = ll_copy_str(rc.base_url);
 	else	bu = 0;
 	unlock_base_url();
 
@@ -3768,20 +3768,20 @@ L_CHAR * bu;
 			continue;
 		}
 
-		n = new_queue_node(sizeof(*n),125);
+		n = new_queue_node(sizeof(*n));
 		n->h.key = 0;
 		n->mappath_loading = 0;
 
 		n->lr_crd = w = new_lrw(w);
-		get_url2(&w->url,u->string.data,1556);
+		get_url2(&w->url,u->string.data);
 		if ( l_strcmp(v->string.data,u->string.data) ) {
 			n->lr_obj = w = new_lrw(w);
-			get_url2(&w->url,v->string.data,1556);
+			get_url2(&w->url,v->string.data);
 		}
 		else	n->lr_obj = 0;
 
-		n->crd_path = ll_copy_str(u->string.data,125);
-		n->obj_path = ll_copy_str(v->string.data,236);
+		n->crd_path = ll_copy_str(u->string.data);
+		n->obj_path = ll_copy_str(v->string.data);
 
 
 		if ( bu )
@@ -3881,7 +3881,7 @@ RESOURCE * c;
 REAL1 reso;
 GB_POINT p;
 
-	get_url2(&u,target,1565);
+	get_url2(&u,target);
 
 	c = load_resource(ses,&u,Q_PRI_RADAR);
 
@@ -3901,7 +3901,7 @@ GB_POINT p;
 	if ( rc.base_url )
 		d_f_ree(rc.base_url);
 
-	rc.base_url = ll_copy_str(target,1528);
+	rc.base_url = ll_copy_str(target);
 
 	unlock_base_url();
 
@@ -3939,7 +3939,7 @@ RESOURCE * c;
 
 	if ( list_length(s) == 3 ) {
 
-		get_url2(&u,_crd,1565);
+		get_url2(&u,_crd);
 	
 		c = load_resource(ses,&u,Q_PRI_RADAR);
 		free_url(&u);
@@ -3953,7 +3953,7 @@ RESOURCE * c;
 	}
 	else if ( list_length(s) == 4 ) {
 
-		get_url2(&u,_crd,1565);
+		get_url2(&u,_crd);
 
 		c = load_resource(ses,&u,Q_PRI_RADAR);
 		free_url(&u);
@@ -3981,7 +3981,7 @@ RESOURCE * c;
 	else {
 
 		_rot = 0;
-		get_url2(&u,_crd,1565);
+		get_url2(&u,_crd);
 	
 		c = load_resource(ses,&u,Q_PRI_RADAR);
 set_cpu_msg(108);
@@ -4024,14 +4024,14 @@ set_cpu_msg(108);
 
 	{
 	L_CHAR * tmp;
-		tmp = ll_copy_str(rc.base_url,128);
+		tmp = ll_copy_str(rc.base_url);
 		mpr = resolve_route(_crd,tmp,RR_WM_INDIRECT);
 		d_f_ree(tmp);
 	}
 
 	if ( mpr == 0 || mpr == MP_NO_ROUTE )
 		goto individual;
-	get_url2(&u,_crd,1566);
+	get_url2(&u,_crd);
 	mh = get_mh_from_route(ses,&u,mpr);
 
 	free_url(&u);
@@ -4065,7 +4065,7 @@ individual:
 		d_f_ree(rc.base_url);
 	_free_radar_matrix(rc.matrix);
 	rc.matrix = 0;
-	rc.base_url = ll_copy_str(_crd,1529);
+	rc.base_url = ll_copy_str(_crd);
 	get_center_reso(&p,&reso,&_r);
 	if ( c && c->h.visible_resolution > reso )
 		reso = c->h.visible_resolution*1.1;
@@ -4226,7 +4226,7 @@ int i;
 	if ( w->base_url )
 		d_f_ree(w->base_url);
 	if ( rc.base_url )
-		w->base_url = ll_copy_str(rc.base_url,234);
+		w->base_url = ll_copy_str(rc.base_url);
 	else	w->base_url = 0;
 	unlock_base_url();
 }
@@ -4340,7 +4340,7 @@ printf("insert_task del %i\n",get_tid());
 				if ( rc.base_url )
 					d_f_ree(rc.base_url);
 				rc.base_url = 
-					ll_copy_str(n->crd_path,1530);
+					ll_copy_str(n->crd_path);
 				reso = get_win_rect(&r);
 				lock_task(radar_lock);
 				rc.first_max = rc.win_reso_max = reso;
@@ -4626,8 +4626,8 @@ retry:
 	}
 do_ptr:
 
-	b_url = ll_copy_str(rc.base_url,236);
-	c_path = ll_copy_str(c->crd_path,356);
+	b_url = ll_copy_str(rc.base_url);
+	c_path = ll_copy_str(c->crd_path);
 	
 	_unlock_base_url();
 	unlock_task(radar_lock,"min_route_radar");
