@@ -79,7 +79,7 @@ set_t_msg(55);
 		ret = 0;
 		goto end;
 	}
-	wf = d_alloc(sizeof(*wf),83);
+	wf = d_alloc(sizeof(*wf));
 	wf->pri_adj = 0;
 	wf->id = _get_new_wfid();
 	wf->tbl = tbl;
@@ -91,7 +91,7 @@ set_t_msg(55);
 /*
 	draw->c.weight = 0;
 */
-	wf->pixels = d_alloc(env.win_width * env.win_height * sizeof(long),84);
+	wf->pixels = d_alloc(env.win_width * env.win_height * sizeof(long));
 	for ( i = 0 ; i < env.win_width * env.win_height ; i ++ )
 		wf->pixels[i] = C_TRANSPARENT|C_DIRTY;
 	if ( env.flame_base == 0  ) {
@@ -279,9 +279,9 @@ int id;
 		lp = 1;
 	w = r->br.x - r->tl.x;
 	h = r->br.y - r->tl.y;
-	pt_list = d_alloc(w*h*sizeof(GB_POINT),85);
-	pt_reso = d_alloc(w*h*sizeof(REAL1),86);
-	buf = d_alloc(w*h*sizeof(long),87);
+	pt_list = d_alloc(w*h*sizeof(GB_POINT));
+	pt_reso = d_alloc(w*h*sizeof(REAL1));
+	buf = d_alloc(w*h*sizeof(long));
 	i = 0;
 	for ( yy = r->tl.y ; yy < r->br.y ; yy+= lp )
 		for ( xx = r->tl.x ; xx < r->br.x ; xx += lp ) {
@@ -419,7 +419,7 @@ int i;
 		break;
 	case WFT_PLOT:
 		wf->pixels = d_alloc(env.win_width * env.win_height 
-				* sizeof(long),84);
+				* sizeof(long));
 		for ( i = 0 ; i < env.win_width * env.win_height ; i ++ )
 			wf->pixels[i] = C_TRANSPARENT|C_DIRTY;
 		break;
@@ -583,9 +583,9 @@ int ci_ret;
 
 	w = r->br.x - r->tl.x;
 	h = r->br.y - r->tl.y;
-	pt_list = d_alloc(w*h*sizeof(GB_POINT),88);
-	pt_reso = d_alloc(w*h*sizeof(REAL1),89);
-	buf = d_alloc(w*h*sizeof(long),90);
+	pt_list = d_alloc(w*h*sizeof(GB_POINT));
+	pt_reso = d_alloc(w*h*sizeof(REAL1));
+	buf = d_alloc(w*h*sizeof(long));
 	i = 0;
 
 
