@@ -124,7 +124,7 @@ retry:
 	if ( wf->lock >= 0 ) {
 		wf->lock ++;
 
-		wfl = d_alloc(sizeof(*wfl),33);
+		wfl = d_alloc(sizeof(*wfl));
 		wfl->next = wf->lock_list;
 		wfl->tid = get_tid();
 		wf->lock_list  = wfl;
@@ -157,7 +157,7 @@ set_t_msg(4);
 	}
 	wf->lock = -1;
 
-	wfl = d_alloc(sizeof(*wfl),33);
+	wfl = d_alloc(sizeof(*wfl));
 	wfl->next = wf->lock_list;
 	wfl->tid = get_tid();
 	wf->lock_list  = wfl;
@@ -580,7 +580,7 @@ set_t_msg(15);
 	ret = 0;
 	if ( cmd == ISI_INFO )
 		goto end2;
-	si = d_alloc(sizeof(*si),1505);
+	si = d_alloc(sizeof(*si));
 	si->rno = rno;
 	si->code = code;
 	si->sub = sub;
@@ -589,7 +589,7 @@ set_t_msg(15);
 	si->data = data;
 	si->alpha = alpha;
 	if ( ref )
-		si->ref = ll_copy_str(ref,1537);
+		si->ref = ll_copy_str(ref);
 	else	si->ref = 0;
 	si->next = wf->sym_i;
 	wf->sym_i = si;
@@ -1338,7 +1338,7 @@ VPOINT * ixp;
 			reso_c_unit(&r->h.cu),
 			l_string(std_cm,"dot/rad"));
 
-	gt.ix = d_alloc(sizeof(VPOINT)*w*h,123);
+	gt.ix = d_alloc(sizeof(VPOINT)*w*h);
 	gt.radius = radius;
 	if ( wf_make_gmatrix_index(gt.ix,
 			gb_from = v2gb_point(from),
@@ -1356,8 +1356,8 @@ VPOINT * ixp;
 
 	_wf_purge_select();
 
-	_rp = rp = d_alloc(w*h,135);
-	_rpp = rpp = d_alloc(sizeof(long)*w*h,1552);
+	_rp = rp = d_alloc(w*h);
+	_rpp = rpp = d_alloc(sizeof(long)*w*h);
 	ixp = gt.ix;
 	for ( y = 0 ; y < h ; y ++ )
 		for ( x = 0 ; x < w ; x ++ , ixp ++ , rp ++ , rpp ++ ) {
@@ -1431,7 +1431,7 @@ set_t_msg(26);
 		unlock_task(env.wf_lock,"wf_get_coordinate_info");
 		return;
 	}
-	reso = d_alloc(sizeof(REAL1)*ptr_len,234);
+	reso = d_alloc(sizeof(REAL1)*ptr_len);
 	for ( i = 0 ; i < ptr_len ; i ++ )
 		reso[i] = 1;
 	mh = add_mh(&env.flame_base_display_map,wf->mh);
@@ -1453,7 +1453,7 @@ wf_im_zoom_proc(
 {
 unsigned long *buf;
 int x,y,xx,yy,i;
-	buf = d_alloc(sizeof(long)*w*h,91);
+	buf = d_alloc(sizeof(long)*w*h);
 	i = 0;
 	for ( y = 0 ; y < h ; y ++ )
 		for ( x = 0 ; x < w ; x ++ ) {
@@ -1490,8 +1490,8 @@ set_t_msg(27);
 
 	ow = env.win_width;
 	oh = env.win_height;
-	index_x = d_alloc(sizeof(int)*ow,92);
-	index_y = d_alloc(sizeof(int)*oh,93);
+	index_x = d_alloc(sizeof(int)*ow);
+	index_y = d_alloc(sizeof(int)*oh);
 	wf_make_zoom_index(index_x,index_y,zoom,ow,oh);
 	for ( wf = env.flame ; wf ; wf = wf->next ) {
 		if ( wf->flags & WFF_FREE )
@@ -1624,7 +1624,7 @@ int y_src,y_dest,y_max,x,x_ofs;
 	w = p->r.r.br.x - p->r.r.tl.x;
 	h = p->r.r.br.y - p->r.r.tl.y;
 
-	p->r.plane = d_alloc(w*h*sizeof(unsigned long),125);
+	p->r.plane = d_alloc(w*h*sizeof(unsigned long));
 
 	y_max = p->r.r.br.y;
 	y_dest = 0;
@@ -1912,7 +1912,7 @@ set_t_msg(32);
 				if ( sts && si->ref ) {
 printf("REFERENCE\n");
 					sts->reference 
-						= ll_copy_str(si->ref,123);
+						= ll_copy_str(si->ref);
 					sts->flags |= SF_REFERENCE;
 
 					unlock_task(env.wf_lock,"set_change");
@@ -1922,7 +1922,7 @@ printf("REFERENCE\n");
 				no_cnt ++;
 			}
 			if ( no_cnt ) {
-				no_list = d_alloc(no_cnt*2*sizeof(int),1);
+				no_list = d_alloc(no_cnt*2*sizeof(int));
 				i = 0;
 				for ( si = wf->sym_i ; si ; si = si->next ) {
 					if ( !(si->flags & SIF_ANCOR) )
@@ -2057,7 +2057,7 @@ int size;
 int ses;
 int er;
 
-	get_url2(&u,url,1570);
+	get_url2(&u,url);
 	if ( u.proto == 0 || u.db == 0 || u.server == 0 || u.resource == 0 )
 		return 0;
 	lock_task(env.wf_lock);
@@ -2198,7 +2198,7 @@ int ret;
 		sw.color.rev_t = 0;
 		sw.width = env.win_width;
 		sw.height = env.win_height;
-		si = d_alloc(sizeof(*si),96);
+		si = d_alloc(sizeof(*si));
 		sw.si = si;
 		si->pixels = 0;
 		select_resource(wf->draw,&sw);
@@ -2394,7 +2394,7 @@ set_t_msg(41);
 		unlock_task(env.wf_lock,"min_route_wf");
 		return ret;
 	}
-	org = ll_copy_str(get_url_str2(&wf->draw->h.entry),1538);
+	org = ll_copy_str(get_url_str2(&wf->draw->h.entry));
 
 	i = cnt;
 	for ( wf = env.flame ; wf && i ; wf = wf->next , i -- ) {
@@ -2405,7 +2405,7 @@ set_t_msg(41);
 		unlock_task(env.wf_lock,"min_route_wf");
 		return ret;
 	}
-	target = ll_copy_str(get_url_str2(&wf->draw->h.entry),1539);
+	target = ll_copy_str(get_url_str2(&wf->draw->h.entry));
 	unlock_task(env.wf_lock,"min_route_wf");
 
 	mpr = resolve_route(org,target,RR_WM_DIRECT_NO_WAIT);
@@ -2416,7 +2416,7 @@ set_t_msg(41);
 		ret = -1;
 		goto flush_mpr2;
 	}
-	get_url2(&u,org,1569);
+	get_url2(&u,org);
 	mh = get_mh_from_route(ses,&u,mpr);
 	free_url(&u);
 	if ( mh == MP_MH_NO_ROUTE ) {
@@ -2553,7 +2553,7 @@ _rotate_plane(
 {
 unsigned long * ret, * rp;
 int x,y;
-	ret = d_alloc(sizeof(long)*env.win_width*env.win_height,12);
+	ret = d_alloc(sizeof(long)*env.win_width*env.win_height);
 	rp = ret;
 	for ( y = 0 ; y < env.win_height ; y ++ )
 		for ( x = 0 ; x < env.win_width ; x++ ) {
@@ -2579,7 +2579,7 @@ WIN_FLAME * wf;
 		return 0;
 	lock_task(env.wf_lock);
 set_t_msg(46);
-	index = d_alloc(sizeof(VPOINT)*env.win_width*env.win_height,13);
+	index = d_alloc(sizeof(VPOINT)*env.win_width*env.win_height);
 	wf_make_rotate_index(index,from,to,env.win_width,env.win_height);
 	plane = _rotate_plane(env.redraw_plane,index);
 	d_f_ree(env.redraw_plane);
@@ -2784,7 +2784,7 @@ set_t_msg(49);
 		if ( wf->draw->c.button_action )
 			rlist_len ++;
 	}
-	rlist = d_alloc(sizeof(RESOURCE*)*rlist_len,123);
+	rlist = d_alloc(sizeof(RESOURCE*)*rlist_len);
 	i = 0;
 	for ( wf = env.flame ; wf ; wf = wf->next ) {
 		if ( wf->draw->c.button_action )
@@ -2840,7 +2840,7 @@ set_t_msg(50);
 		e->flame_base_resolution = env.flame_base_resolution;
 		e->flame_base_display_map_type
 			= env.flame_base_display_map.type;
-		e->flame_base_unit = ll_copy_str(r->h.cu.unit,125);
+		e->flame_base_unit = ll_copy_str(r->h.cu.unit);
 
 		e->flags |= SF_RESOLUTION|SF_MAP_TYPE|SF_UNIT;
 
@@ -2962,7 +2962,7 @@ set_t_msg(54);
 	oh = env.win_height;
 	gbp->r.r.tl.x = gbp->r.r.br.x = 0;
 	gbp->r.r.tl.y = gbp->r.r.br.y = -1;
-	gbp->r.plane = buf = d_alloc(sizeof(unsigned long)*ow*oh,125);
+	gbp->r.plane = buf = d_alloc(sizeof(unsigned long)*ow*oh);
 	gbp->h.type = GPT_REDRAW;
 	for ( i = 0 ; i < ow*oh ; i ++ , buf ++ )
 		*buf = C_TRANSPARENT;
