@@ -183,7 +183,7 @@ XL_SEXP * remote_fetch_lump();
 
 	gc_push(0,0,"check_lump_path");
 
-	get_url2(&u,info.crd,1234);
+	get_url2(&u,info.crd);
 	lump = remote_fetch_lump(ses,&u);
 	if ( lump == 0 ) {
 		ret = -1;
@@ -285,8 +285,8 @@ LUMP_AROUND_LIST * al1;
 			dt = get_el(el,1);
 			if ( get_type(dt) != XLT_STRING )
 				continue;
-			al1 = d_alloc(sizeof(*al1),123);
-			al1->url = ll_copy_str(dt->string.data,1391);
+			al1 = d_alloc(sizeof(*al1));
+			al1->url = ll_copy_str(dt->string.data);
 			al1->next = a;
 			a = al1;
 		}
@@ -361,7 +361,7 @@ compose_lr(URL * u,LUMP_ROUTE * lr1,LUMP_ROUTE * lr2,L_CHAR * comein)
 LUMP_ROUTE * lr3, * lr4, * lr5;
 URL uu;
 	for ( lr3 = lr2 ; lr3 ; lr3 = lr3->next ) {
-		get_url2(&uu,lr3->dir,1239);
+		get_url2(&uu,lr3->dir);
 		if ( url_cmp(u,&uu) == 0 ) {
 			free_url(&uu);
 			continue;
@@ -373,7 +373,7 @@ URL uu;
 				lr4->distance = lr3->distance + 1;
 				if ( lr4->dir )
 					d_f_ree(lr4->dir);
-				lr4->dir = ll_copy_str(comein,1390);
+				lr4->dir = ll_copy_str(comein);
 			}
 		}
 		else {
@@ -414,18 +414,18 @@ int p;
 		local_ip = get_localhostip();
 
 	p = get_my_port();
-	get_url2(u,url_str,1240);
+	get_url2(u,url_str);
 	if ( u->proto == 0 )
 		u->proto = nl_copy_str(std_cm,"xlp");
 	if ( u->server == 0 )
-		u->server = ll_copy_str(gblisp_site,1389);
+		u->server = ll_copy_str(gblisp_site);
 	if ( u->port == 0 )
 		u->port = p;
 	if ( u->db[0] != '/' ) {
 	L_CHAR * buf;
 	int len;
 		len = l_strlen(u->db);
-		buf = d_alloc(sizeof(L_CHAR)*(len+2),23);
+		buf = d_alloc(sizeof(L_CHAR)*(len+2));
 		l_strcpy(&buf[1],u->db);
 		buf[0] = '/';
 		d_f_ree(u->db);
@@ -567,7 +567,7 @@ L_CHAR * path;
 XL_SEXP * gt;
 	p = get_my_port();
 	local_ip = get_localhostip();
-	get_url2(&u,url,1241);
+	get_url2(&u,url);
 	if ( u.server == 0 && u.port == 0 ) {
 		u.port = p;
 	}
@@ -648,7 +648,7 @@ LUMP_ROUTE * lrp;
 	same = 0;
 	other = 0;
 	for ( lrp = lr ; lrp ; lrp = lrp->next ) {
-		get_url2(&u,lrp->lump_crd,1242);
+		get_url2(&u,lrp->lump_crd);
 		if ( l_strcmp(u.server,me->server) == 0 &&
 				u.port == me->port )
 			same ++;
@@ -682,12 +682,12 @@ int same,other;
 	lr0 = lr;
 	lr = lr->next;
 
-	get_url2(&me,lr0->lump_crd,1243);
+	get_url2(&me,lr0->lump_crd);
 
 	same = 0;
 	other = 0;
 	for ( ; lr ; lr = lr->next ) {
-		get_url2(&u,lr->lump_crd,1244);
+		get_url2(&u,lr->lump_crd);
 		if ( l_strcmp(u.server,me.server) == 0 &&
 				u.port == me.port ) {
 			if ( lr->pri <= lr0->pri )
@@ -765,7 +765,7 @@ unsigned int now;
 
 	get_my_url(&u1,filename);
 
-	cc = ll_copy_str(get_url_str2(&u1),1388);
+	cc = ll_copy_str(get_url_str2(&u1));
 	ret = local_fetch(0,&u1,".lmp");
 	my_lr = get_lr(&opt,ret,cc);
 	d_f_ree(cc);
@@ -776,7 +776,7 @@ unsigned int now;
 
 	lr = get_dist0(my_lr);
 	for ( a1 = a ; a1 ; a1 = a1->next ) {
-		get_url2(&u2,a1->url,1245);
+		get_url2(&u2,a1->url);
 		gc_push(0,0,"check_my_lump");
 		if ( l_strcmp(u2.server,u1.server) == 0 &&
 				u2.port == u1.port )
@@ -838,7 +838,7 @@ unsigned int now;
 		if ( opt.lump == 0 ) {
 		LUMP_INFO info;
 		new:
-			info.crd = ll_copy_str(get_url_str2(&u1),1387);
+			info.crd = ll_copy_str(get_url_str2(&u1));
 			opt.lump = get_lump_path(new_lump());
 
 log_printf(LOG_DEBUG,"new lump = %s",n_string(std_cm,opt.lump));
@@ -955,7 +955,7 @@ set_cpu_msg(572);
 	copy_url(&u2,u);
 	if ( u2.db )
 		d_f_ree(u2.db);
-	u2.db = ll_copy_str(db,1386);
+	u2.db = ll_copy_str(db);
 	if ( u2.resource )
 		d_f_ree(u2.resource);
 	u2.resource = nl_copy_str(std_cm,"db.pmd");
@@ -1011,7 +1011,7 @@ unsigned int _ret,__ret;
 	len = l_strlen(crd);
 	if ( l_strcmp(&crd[len-4],l_string(std_cm,".crd")) )
 		return 0;
-	get_url2(&u1,crd,1246);
+	get_url2(&u1,crd);
 
 	r = remote_fetch_lump(ses,&u1);
 
@@ -1019,7 +1019,7 @@ unsigned int _ret,__ret;
 
 	for ( lr1 = lr ; lr1 ; lr1 = lr1->next ) {
 		init_lump_opt(&opt2);
-		get_url2(&u2,lr1->lump_crd,1247);
+		get_url2(&u2,lr1->lump_crd);
 		r2 = remote_fetch_lump(ses,&u2);
 		lr2 = get_lr(&opt2,r2,0);
 		free_lr(lr2);
