@@ -41,7 +41,7 @@ send_trigger(L_CHAR * filename)
 {
 L_CHAR * _filename;
 int pp;
-	_filename = ll_copy_str(filename,1446);
+	_filename = ll_copy_str(filename);
 	pp = l_strlen(_filename)-1;
 	for ( ; pp >= 0 && _filename[pp] != '.' ; pp -- );
 	if ( pp < 0 )
@@ -247,7 +247,7 @@ L_CHAR * _file;
 int p1;
 char buf[100];
 
-	_file = ll_copy_str(filename,1445);
+	_file = ll_copy_str(filename);
 	for ( p1 = l_strlen(_file)-1 ; p1 >= 0 ; p1 -- )
 		if ( _file[p1] == '.' )
 			break;
@@ -256,9 +256,9 @@ char buf[100];
 	_file[p1] = 0;
 
 	where = 0;
-	get_url2(&u_src,src,1208);
-	get_url2(&u_dest,dest,1209);
-	get_url2(&u_map,map,1210);
+	get_url2(&u_src,src);
+	get_url2(&u_dest,dest);
+	get_url2(&u_map,map);
 	if ( u_src.proto == 0 || u_src.server == 0 ||
 			u_src.db == 0 || u_src.resource == 0 )
 		goto url_error;
@@ -303,7 +303,7 @@ char buf[100];
 	}
 	db_res = d_alloc(((len=l_strlen(u_me->db))
 				+l_strlen(u_me->resource)+2)
-			*sizeof(L_CHAR),671);
+			*sizeof(L_CHAR));
 	l_strcpy(db_res,u_me->db);
 	l_strcpy(&db_res[len],u_me->resource);
 	if ( l_strcmp(_file,db_res) ) {
@@ -395,9 +395,9 @@ URL _u;
 			r1 = cons(r2,r1);
 			continue;
 		}
-		get_url2(&_u,u->string.data,1211);
+		get_url2(&_u,u->string.data);
 		d_f_ree(_u.server);
-		_u.server = ll_copy_str(gblisp_site,1444);
+		_u.server = ll_copy_str(gblisp_site);
 		r1 = cons(List(sym,
 				get_string(get_url_str2(&_u)),
 				-1),
