@@ -82,11 +82,11 @@ char * xx_copy_str(char *,char *,int);
 
 
 L_CHAR * xx_ll_copy_str(L_CHAR *,char *,int);
-#define ll_copy_str(p,no)	xx_ll_copy_str((p),__FILE__,__LINE__)
+#define ll_copy_str(p)	xx_ll_copy_str((p),__FILE__,__LINE__)
 L_CHAR * nl_copy_str(CODE_METHOD *,char *);
 char * ln_copy_str(CODE_METHOD *,L_CHAR*);
 int get_url(URL *,L_CHAR *);
-int get_url2(URL *,L_CHAR *,int);
+int get_url2(URL *,L_CHAR *);
 int url_cmp(URL *,URL *);
 void zero_url(URL *);
 void free_url(URL *);
