@@ -31,7 +31,7 @@ int size;
 char buf[20],* bp;
 int ptr;
 	size = l_strlen(str)+10;
-	ret_str = d_alloc(size*sizeof(L_CHAR),1655);
+	ret_str = d_alloc(size*sizeof(L_CHAR));
 	ptr = 0;
 	for ( ; *str ; str ++ ) {
 		ch = *str;
